Circle
======

.. currentmodule:: pywwt.annotation

.. autoclass:: Circle
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Circle.fill
      ~Circle.fill_color
      ~Circle.line_color
      ~Circle.line_width
      ~Circle.radius
      ~Circle.shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~Circle.set_center

   .. rubric:: Attributes Documentation

   .. autoattribute:: fill
   .. autoattribute:: fill_color
   .. autoattribute:: line_color
   .. autoattribute:: line_width
   .. autoattribute:: radius
   .. autoattribute:: shape

   .. rubric:: Methods Documentation

   .. automethod:: set_center
